Crate libyal_rs_common_build

Functions

build_lib
Build the lib on posix platforms (using configure and make). Note, this function will not sync dependencies. use sync_libs or sync_and_build_lib. This function will also add the needed folder to the link-search path. Return the “include” folder for the library (to be used by bindgen).
generate_bindings
get_lib_and_copy_to_out_dir
Find the library (based on env var or using the local submodule), copy it to the output folder and return the copied folder’s path.
sync_and_build_lib
Sync dependencies and build the lib. See build_lib for more.
sync_libs
Synchronizes the local library dependencies.